# Rogvibe

Terminal lottery wheel built with [Textual](https://github.com/Textualize/textual): press Space to spin the wheel and randomly pick a participant.

<img width="1280" height="762" alt="image" src="https://github.com/user-attachments/assets/4ef4e440-a6aa-4dd0-9d92-861c979bfdde" />


https://github.com/user-attachments/assets/f819f175-acd0-48c4-af22-c9d1a7134d73



## Quick start

```cli
uvx rogvibe
# or
pip install rogvibe
rogvibe
# or
uv tool install --python 3.13 rogvibe
rogvibe
```

777 slot mode

```cli
uvx rogvibe --slot
```

https://github.com/user-attachments/assets/57cb32b2-dd64-4200-9134-1f8daeec7ddf
